==> corosync-0.95.tar.gz: corosync-0.95/include/corosync/ipc_pload.h <==
/*
 * Copyright (c) 2008 Red Hat, Inc.
 *
 * All rights reserved.
 *
 * Author: Steven Dake (sdake@redhat.com)
 *
 * This software licensed under BSD license, the text of which follows:
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * - Neither the name of the MontaVista Software, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef IPC_PLOAD_H_DEFINED
#define IPC_PLOAD_H_DEFINED

#include <corosync/corotypes.h>
#include "pload.h"
#include "ipc_gen.h"

enum req_lib_evs_types {
	MESSAGE_REQ_PLOAD_START = 0,
};

enum res_lib_evs_types {
	MESSAGE_RES_PLOAD_START = 0,
};

struct res_lib_pload_start {
	mar_res_header_t header;
	unsigned int dataset[1024];
};

struct res_lib_pload_mcast {
	mar_res_header_t header;
};

struct req_lib_pload_start {
	mar_req_header_t header;
	unsigned int msg_code;
	unsigned int msg_size;
	unsigned int msg_count;
	unsigned int time_interval;
};

struct req_lib_pload_mcast {
	mar_req_header_t header;
	unsigned int code;
};

#endif /* IPC_PLOAD_H_DEFINED */

==> corosync_1.2.1.orig.tar.gz: corosync-1.2.1/include/corosync/ipc_pload.h <==
/*
 * Copyright (c) 2008 Red Hat, Inc.
 *
 * All rights reserved.
 *
 * Author: Steven Dake (sdake@redhat.com)
 *
 * This software licensed under BSD license, the text of which follows:
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 * - Neither the name of the MontaVista Software, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef IPC_PLOAD_H_DEFINED
#define IPC_PLOAD_H_DEFINED

#include <corosync/corotypes.h>
#include <corosync/mar_gen.h>

enum req_lib_evs_types {
	MESSAGE_REQ_PLOAD_START = 0,
};

enum res_lib_evs_types {
	MESSAGE_RES_PLOAD_START = 0,
};

struct res_lib_pload_start {
	coroipc_response_header_t header;
	unsigned int dataset[1024];
};

struct res_lib_pload_mcast {
	coroipc_response_header_t header;
};

struct req_lib_pload_start {
	coroipc_request_header_t header;
	unsigned int msg_code;
	unsigned int msg_size;
	unsigned int msg_count;
	unsigned int time_interval;
};

struct req_lib_pload_mcast {
	coroipc_request_header_t header;
	unsigned int code;
};

#endif /* IPC_PLOAD_H_DEFINED */
